BbRethEngineApiServer

Trait BbRethEngineApiServer 

pub trait BbRethEngineApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required methods
    fn reth_new_payload<'life0, 'async_trait>(
        &'life0 self,
        payload: RethNewPayloadInput<ExecutionData>,
        wait_for_persistence: Option<bool>,
        wait_for_caches: Option<bool>,
        big_block_data: Option<BigBlockData<ExecutionData>>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<RethPayloadStatus>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn reth_forkchoice_updated<'life0, 'async_trait>(
        &'life0 self,
        forkchoice_state: ForkchoiceState,
    ) -> Pin<Box<dyn Future<Output = RpcResult<ForkchoiceUpdated>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the BbRethEngineApi RPC API.

Required Methods

fn reth_new_payload<'life0, 'async_trait>( &'life0 self, payload: RethNewPayloadInput<ExecutionData>, wait_for_persistence: Option<bool>, wait_for_caches: Option<bool>, big_block_data: Option<BigBlockData<ExecutionData>>, ) -> Pin<Box<dyn Future<Output = RpcResult<RethPayloadStatus>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

reth_newPayload with optional big-block data.

fn reth_forkchoice_updated<'life0, 'async_trait>( &'life0 self, forkchoice_state: ForkchoiceState, ) -> Pin<Box<dyn Future<Output = RpcResult<ForkchoiceUpdated>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

reth_forkchoiceUpdated – pass-through.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors